@@ -24,6 +24,11 @@
 # USA
 
 import os
+if os.name == "posix":
+    import dbus
+elif os.name == "nt":
+    import win32api
+    import win32con
 
 import gtk
 import pango
@@ -56,6 +61,7 @@ class AdminConsole:
         self.help_button.connect ('clicked', self.__on_help_button_clicked)
         self.close_button.connect ('clicked', self.__on_close_button_clicked)
         self.apply_button.connect ('clicked', self.__on_apply_button_clicked)
+        self.unlock_button.connect('clicked', self.__on_unlock_button_clicked)
 
         self.session_hoursday_checkbutton.connect ('toggled', self.__on_session_hoursday_checkbutton_toggled)
         self.session_hoursday_spinbutton.connect ('value-changed', self.__on_session_hoursday_spinbutton_changed)
@@ -68,6 +74,8 @@ class AdminConsole:
         self.im_hoursday_checkbutton.connect ('toggled', self.__on_im_hoursday_checkbutton_toggled)
         self.im_hoursday_spinbutton.connect ('value-changed', self.__on_im_hoursday_spinbutton_changed)
 
+        
+
         self.session_schedule_widget = nanny.client.gnome.admin.ScheduleCalendar()
         self.session_schedule_alignment.add (self.session_schedule_widget)
         self.session_schedule_alignment.show_all()
@@ -99,6 +107,49 @@ class AdminConsole:
         self.window.set_position (gtk.WIN_POS_CENTER)
         self.window.show_all ()
 
+        self.__lock_widgets()
+
+    def __lock_widgets(self) :
+        lock_status = self.dbus_client.is_unlocked()
+        if lock_status == True :
+            self.unlock_area.hide()
+        else:
+            self.unlock_area.show()
+
+        self.apply_button.set_sensitive(lock_status)
+
+        self.session_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.session_hoursday_spinbutton.set_sensitive(self.session_hoursday_checkbutton.get_active())
+        else:
+            self.session_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.browser_configure_proxy_button.set_sensitive(lock_status)
+        self.browser_use_proxy_checkbutton.set_sensitive(lock_status)
+        self.browser_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.browser_hoursday_spinbutton.set_sensitive(self.browser_hoursday_checkbutton.get_active())
+        else:
+            self.browser_hoursday_spinbutton.set_sensitive(lock_status)
+        
+        self.mail_hoursday_checkbutton.set_sensitive(lock_status)
+        self.mail_hoursday_spinbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.mail_hoursday_spinbutton.set_sensitive(self.mail_hoursday_checkbutton.get_active())
+        else:
+            self.mail_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.im_hoursday_checkbutton.set_sensitive(lock_status)
+        if lock_status == True:
+            self.im_hoursday_spinbutton.set_sensitive(self.im_hoursday_checkbutton.get_active())
+        else:
+            self.im_hoursday_spinbutton.set_sensitive(lock_status)
+
+        self.session_schedule_widget.set_sensitive(lock_status)
+        self.browser_schedule_widget.set_sensitive(lock_status)
+        self.mail_schedule_widget.set_sensitive(lock_status)
+        self.im_schedule_widget.set_sensitive(lock_status)
+
     def __create_users_treeview (self):
         # UID
         col = gtk.TreeViewColumn ('uid')
@@ -133,13 +184,34 @@ class AdminConsole:
         model = self.users_treeview.get_model ()
         treeselection = self.users_treeview.get_selection()
         for uid, name, user_name in self.dbus_client.list_users ():
-            face_file = '/home/%s/.face' % name
+            print "uid: %s, name: %s, user_name: %s" % (uid, name, user_name)
+            if os.name == "posix" :
+                face_file = '/home/%s/.face' % name
+            elif os.name == "nt" :
+                import glob
+                all_users_path = os.environ["ALLUSERSPROFILE"]
+                face_file = None
+                for p in glob.glob(os.path.join(all_users_path, "*", "Microsoft", "User Account Pictures", "%s.bmp" % name)):
+                    face_file = p
+                    print face_file
+                    break          
+                
+                if face_file == None:
+                    face_file = "/fake/path"
+
             if os.path.exists (face_file):
                 pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(face_file, 50, 50)
             else:
-                icon_theme = gtk.IconTheme ()
-                pixbuf = icon_theme.load_icon ('nobody', 50, gtk.ICON_LOOKUP_USE_BUILTIN)
-            model.append ([uid, pixbuf, user_name])
+                if os.name == "posix" :
+                    icon_theme = gtk.IconTheme ()
+                    pixbuf = icon_theme.load_icon ('nobody', 50, gtk.ICON_LOOKUP_USE_BUILTIN)
+                elif os.name == "nt" :
+                    pixbuf = None
+
+            if len(user_name) > 0 :
+                model.append ([uid, pixbuf, user_name])
+            else:
+                model.append ([uid, pixbuf, name])
         treeselection.set_mode (gtk.SELECTION_SINGLE)
         self.users_selection_change_cb_id = treeselection.connect ("changed", self.__on_users_treeview_selection_changed)
 
@@ -266,6 +338,7 @@ class AdminConsole:
         dialog = gtk.MessageDialog(None, 0, gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE,
                                    _("Your configuration has been saved") )
         dialog.set_property("icon-name", "nanny")
+        dialog.set_transient_for(self.window)
         dialog.set_default_response(gtk.RESPONSE_CLOSE)
         dialog.run()
         dialog.destroy()
@@ -311,6 +384,8 @@ class AdminConsole:
             self.__selected_user_id = None
             self.window.set_title (_('Nanny Admin Console'))
 
+        self.__lock_widgets()
+
     def __on_session_hoursday_spinbutton_changed (self, widget, data=None):
         self.__config_changed = True
     def __on_session_hoursday_checkbutton_toggled (self, widget, data=None):
@@ -348,7 +423,19 @@ class AdminConsole:
             self.im_hoursday_spinbutton.set_sensitive (False)
 
     def __on_help_button_clicked (self, widget, data=None):
-       	gtk.show_uri(None , "ghelp:nanny", gtk.get_current_event_time()) 
+        if os.name == "posix":
+            try:
+                gtk.show_uri(None , "ghelp:nanny", gtk.get_current_event_time())
+            except:
+                os.system("yelp ghelp:nanny")
+        elif os.name == "nt":
+            win32api.ShellExecute(None, "open", 
+                                  "http://library.gnome.org/users/nanny/stable/",
+                                  None, None, win32con.SW_SHOWNORMAL)
+
+    def __on_unlock_button_clicked (self, widget, data=None):
+        self.dbus_client.unlock()
+        self.__lock_widgets()
 
     def __on_close_button_clicked (self, widget, data=None):
         gtk.main_quit()
