@@ -25,11 +25,25 @@
 
 
 import os
+import sys
 import gtk
 
-share_files_dir= os.path.join("/usr/local","share/","nanny/client/gnome/admin/")
-ui_files_dir= os.path.join(share_files_dir,"ui/")
-icons_files_dir= os.path.join(share_files_dir,"icons/")
+if os.name == "posix" :
+    share_files_dir= os.path.join("/usr","share/","nanny/client/gnome/admin/")
+elif os.name == "nt":
+    if not hasattr(sys, "frozen") :
+        file_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+        for x in range(8):
+            file_dir = os.path.dirname(file_dir)
+
+        root_path = file_dir
+        share_files_dir = os.path.join(root_path, "share" , "nanny", "client", "gnome", "admin")
+    else:
+        root_path = os.path.dirname(os.path.dirname(unicode(sys.executable, sys.getfilesystemencoding( ))))
+        share_files_dir = os.path.join(root_path, "share" , "nanny", "client", "gnome", "admin")
+
+ui_files_dir= os.path.join(share_files_dir,"ui")
+icons_files_dir= os.path.join(share_files_dir,"icons")
 
 from AdminConsole import AdminConsole
 from ConfigureProxyDialog import ConfigureProxyDialog
