@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2009 Junta de Andalucia
+# Copyright (C) 2009,2010 Junta de Andalucia
 # 
 # Authors:
 #   Roberto Majadas <roberto.majadas at openshine.com>
@@ -23,9 +23,13 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
 # USA
 
+import os
 from QuarterBack import QuarterBack
-from NannyDBus import NannyDBus
 
+if os.name == "posix":
+    from NannyDBus import NannyDBus
+elif os.name == "nt":
+    from NannyPyroBus import start_pyro_bus
 import nanny.daemon.proxy
 
 import signal
@@ -35,6 +39,17 @@ import os
 class Daemon :
     def __init__(self, app):
         self.quarterback = QuarterBack(app)
-        self.bus = NannyDBus(self.quarterback)
-        
 
+        if os.name == "posix" :
+            self.bus = NannyDBus(self.quarterback)
+	elif os.name == "nt" :
+            from twisted.internet import reactor
+            start_pyro_bus(self.quarterback)
+        
+    def win32_service_stop(self):
+        self.quarterback.win32top.stop()
+        self.quarterback.firewall_filter.stop()
+        self.quarterback.filter_manager.stop()
+        self.quarterback.webcontent_filter.stop()
+        self.quarterback.session_filter.stop()
+    
