@@ -25,18 +25,28 @@
 
 import gobject
 import os
+import sys
+
 import copy
 import pickle
 import time
 from datetime import datetime, timedelta
 
-from LinuxFiltering import LinuxFiltering as FirewallFilter
-from LinuxWebContentFiltering import LinuxWebContentFiltering as WebContentFilter
-from LinuxUsersManager import LinuxUsersManager as UsersManager
-from LinuxSessionCKFiltering import LinuxSessionCKFiltering as SessionFilter
-from FilterManager import FilterManager as FilterManager
-
-from Chrono import Chrono
+if os.name == "posix" :
+    from LinuxFiltering import LinuxFiltering as FirewallFilter
+    from LinuxWebContentFiltering import LinuxWebContentFiltering as WebContentFilter
+    from LinuxUsersManager import LinuxUsersManager as UsersManager
+    from LinuxSessionCKFiltering import LinuxSessionCKFiltering as SessionFilter
+    from FilterManager import FilterManager as FilterManager
+    from Chrono import Chrono
+elif os.name == "nt" :
+    from Win32Filtering import Win32Filtering as FirewallFilter
+    from Win32WebContentFiltering import Win32WebContentFiltering as WebContentFilter
+    from Win32UsersManager import Win32UsersManager as UsersManager
+    from Win32SessionFiltering import Win32SessionFiltering as SessionFilter
+    from FilterManager import FilterManager as FilterManager
+    from Win32Chrono import Win32Chrono as Chrono
+    from Win32Top import Win32Top
 
 
 def GetInHM(m):
@@ -46,7 +56,20 @@ def GetInHM(m):
     minutes = seconds / 60
     return "%02d:%02d" % (hours, minutes)
 
-BLOCK_DB="/var/lib/nanny/nanny-block.db"
+
+if os.name == "posix" :
+    BLOCK_DB = "/var/lib/nanny/nanny-block.db"
+elif os.name == "nt" :
+    if not hasattr(sys, "frozen") :
+        file_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+        for x in range(6):
+            file_dir = os.path.dirname(file_dir)
+        root_path = file_dir
+        
+        BLOCK_DB = os.path.join(root_path, "var", "lib", "nanny", "nanny-block.db")
+    else:
+        BLOCK_DB = os.path.join(os.environ["ALLUSERSPROFILE"], "Gnome", "nanny", "nanny-block.db")
+
 
 WEEKDAYS = ["sun", "mon", "tue", "wed", "thu", "fri", "sat"]
 
@@ -92,6 +115,8 @@ class QuarterBack(gobject.GObject) :
 
         self.__next_update_info = None
         self.usersmanager = UsersManager()
+        if os.name == "nt" :
+             self.win32top = Win32Top(self)
         self.chrono = Chrono(self)
         
         self.firewall_filter = FirewallFilter(self)
@@ -129,6 +154,18 @@ class QuarterBack(gobject.GObject) :
                 available_time = self.get_available_time(user_id, app_id)
                 self.emit("block-status", block_status, user_id, app_id, next_change, available_time)
 
+    def get_block_status_by_uid(self, user_id):
+        if user_id not in self.blocks.keys():
+            return {}
+        
+        ret = {}
+        for app_id in self.blocks[user_id] :
+            block_status, next_change = self.is_blocked(user_id, app_id)
+            available_time = self.get_available_time(user_id, app_id)
+            ret[app_id] = [block_status, next_change, available_time]
+        
+        return ret
+
     def __check_users_info(self):
         some_users_info_changed = False
         if not self.usersmanager.has_changes() :
